exceptiontools.TimeSignatureAssignmentError
===========================================

.. inheritance-diagram:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TimeSignatureAssignmentError.TimeSignatureAssignmentError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
